import { fromEvent } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
/**
 *
 * convenience method to prevent duplicated code. used in strategies after static coalescing
 *
 * @internal
 */
export function afterCoalesceAndSchedule(work, afterCD) {
    work();
    if (afterCD) {
        afterCD();
    }
}
/**
 *
 * convenience method to prevent duplicated code.
 * helper for strategies where we have no direct control over the rendering and thus no information about when
 * rendering was finished. used in native & global strategy
 *
 * @internal
 */
export function afterScheduleCD(tick) {
    let activeAbortController;
    return function (afterCD) {
        if (activeAbortController) {
            activeAbortController.abort();
        }
        activeAbortController = new AbortController();
        if (afterCD) {
            tick()
                .pipe(takeUntil(fromEvent(activeAbortController.signal, 'abort')))
                .subscribe(() => {
                afterCD();
            });
        }
        return activeAbortController;
    };
}
//# sourceMappingURL=util.js.map