"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findRootModule = exports.ROUTING_MODULE_EXT = exports.MODULE_EXT = void 0;
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
const core_1 = require("@angular-devkit/core");
exports.MODULE_EXT = '.module.ts';
exports.ROUTING_MODULE_EXT = '-routing.module.ts';
/**
 * Find the module referred by a set of options passed to the schematics.
 */
function findRootModule(host, module, rootPath = '', skipImport = false) {
    if (skipImport || !module) {
        return undefined;
    }
    const modulePath = core_1.normalize(`${rootPath}/${module}`);
    if (host.exists(modulePath)) {
        return modulePath;
    }
    else if (host.exists(modulePath + '.ts')) {
        return core_1.normalize(modulePath + '.ts');
    }
    else if (host.exists(modulePath + exports.MODULE_EXT)) {
        return core_1.normalize(modulePath + exports.MODULE_EXT);
    }
    else if (host.exists(`${modulePath}/${module}${exports.MODULE_EXT}`)) {
        return core_1.normalize(`${modulePath}/${module}${exports.MODULE_EXT}`);
    }
    else if (host.exists(`${modulePath}/${module}.ts`)) {
        return core_1.normalize(`${modulePath}/${module}.ts`);
    }
    else {
        throw new Error(`Specified module path ${modulePath} does not exist`);
    }
}
exports.findRootModule = findRootModule;
